cgexplore.analysis.ShapeMeasure
===============================

.. currentmodule:: cgexplore.analysis

.. autoclass:: ShapeMeasure
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~ShapeMeasure.calculate
      ~ShapeMeasure.calculate_from_centroids
      ~ShapeMeasure.fill_position_matrix_molecule
      ~ShapeMeasure.get_shape_molecule_byelements
      ~ShapeMeasure.reference_shape_dict
   
   

   
   
   